<?php
/**
 * Plugin Name: MarketMLM API
 * Plugin URI: https://marketmlm.com/
 * Description: MarketMLM wordpress theme REST API.
 * Version: 2.3.5
 * Author: WebHow
 * Author URI: https://marketmlm.com/
 * License: Featured
 * License URI: https://marketmlm.com/terms/
 * Text Domain: mlmr
 * Domain Path: /languages
 */

// Exit if accessed directly.
if( ! defined('ABSPATH') )
{
	exit;
}


/**
 * Plugin initialization
 *
 * @pack WebHow
 */
if( ! class_exists('MlmRest') ):

final class MlmRest
{
	/**
	 * Plugin version
	 */
	private static $mlmr_version = '1.0.0';
	
	
	/**
	 * The one true MlmRest
	 */
	private static $instance;
	
	
	/**
	 * Insures that only one instance of MlmRest exists in memory at any one
	 * time
	 */
	public static function instance()
	{
		if( ! isset( self::$instance ) && ! ( self::$instance instanceof MlmRest ) )
		{
			self::$instance = new MlmRest;
			self::$instance->constants();
			self::$instance->includes();
			
			add_action( 'plugins_loaded', array( self::$instance, 'localization' ) );
			
			self::$instance->routes			= new MlmRestRoutes;
		}
		
		return self::$instance;
	}
	
	
	/**
	 * Constructor
	 */
	protected function __construct()
	{
		
	}
	
	
	/**
	 * Prevent clone
	 */
	private function __clone()
	{
		trigger_error( __( 'You can&rsquo;t do this !', 'mlmr' ), E_USER_ERROR );
	}
	
	
	/**
	 * Disable unserializing of the class
	 */
	private function __wakeup()
	{
		trigger_error( __( 'You can&rsquo;t do this !', 'mlmr' ), E_USER_ERROR );
	}

	
	/**
	 * Define constants
	 *
	 * @pack WebHow
	 */
	private function constants()
	{
		if( ! defined( 'MLMR_PATH' ) )
		{
			define( 'MLMR_PATH', untrailingslashit( plugin_dir_path( __FILE__ ) ) );
		}
		
		if( ! defined( 'MLMR_URL' ) )
		{
			define( 'MLMR_URL', untrailingslashit( plugin_dir_url( __FILE__ ) ) );
		}
	}
	
	
	/**
	 * Localization
	 *
	 * @pack WebHow
	 */
	public function localization()
	{
		load_plugin_textdomain( 'mlmr', false, basename( dirname( __FILE__ ) ) . '/languages' ); 
	}
	

	/**
	 * Include scripts
	 *
	 * @pack WebHow
	 */
	private function includes()
	{
		$files = array(
			trailingslashit( MLMR_PATH ) . 'routes.php'
		);
		
		foreach( $files as $file )
		{
			require_once $file;
		}
	}
	
	
	/**
	 * Plugin activation hook.
	 *
	 * Custom pages, tables and crons.
	 */
	public static function plugin_activated()
	{
		// Add database table.
		global $wpdb;
		$token_table		= $wpdb->prefix . 'mlm_token';
		$charset_collate	= $wpdb->get_charset_collate();
		
		$sql = "CREATE TABLE $token_table (
			id bigint(20) NOT NULL AUTO_INCREMENT,
			user_id bigint(20) NOT NULL,
			access_token varchar(255) NOT NULL,
			refresh_token varchar(255) NOT NULL,
			access_token_valid datetime DEFAULT '0000-00-00 00:00:00' NOT NULL,
			PRIMARY KEY (id),
			UNIQUE KEY key_user_id_token (user_id)
		) $charset_collate;";
		
		require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
		dbDelta( $sql );
		
		// Check version.
		update_option( 'mlmr_version', self::$mlmr_version );
	}
	
	
	/**
	 * Plugin deactivation hook.
	 *
	 * Custom pages, tables and crons.
	 */
	public static function plugin_deactivated()
	{
		//
	}
}

endif; // End if class_exists check.


/**
 * Start it maybe ?!
 *
 * @pack WebHow
 */
function MLMR_On()
{
	return MlmRest::instance();
}


/**
 * This allows you to hook ajax requests.
 *
 * https://codex.wordpress.org/Plugin_API/Action_Reference/wp_ajax_(action)
 */
if( ! function_exists( 'my_ajax' ) )
{
	function my_ajax()
	{
		die( "Hello World" );
	}
	
	add_action( 'wp_ajax_my_ajax', 'my_ajax' );
}


/**
 * Plugin activated !
 */
if( ! function_exists( 'mlmr_activated' ) )
{
	function mlmr_activated()
	{
		MLMR_On()->plugin_activated();
	}
}
register_activation_hook( __FILE__, 'mlmr_activated' );


/**
 * Plugin deactivated !
 */
if( ! function_exists( 'mlmr_deactivated' ) )
{
	function mlmr_deactivated()
	{
		MLMR_On()->plugin_deactivated();
	}
}
register_deactivation_hook( __FILE__, 'mlmr_deactivated' );


// Go on
MLMR_On();